Learn R Programming

nlmixr2est (version 5.0.2)

.agq: Get the adaptive Gauss-Hermite quadrature points and weights

Description

Get the adaptive Gauss-Hermite quadrature points and weights

Usage

.agq(neta = 2, nAGQ = 3)

Value

A list with the following elements:

x

A matrix of quadrature points, one row per point.

w

A matrix of quadrature weights, one row per point.

n

The number of quadrature points.

neta

The number of eta parameters.

nAQD

The number of adaptive quadrature points.

first

A logical indicating if the first point is zero.

Arguments

neta

number of eta parameters in the model

nAGQ

number of adaptive quadrature points to use

Author

Matthew L. Fidler

Examples

Run this code
.agq(neta=2, nAGQ=3)

Run the code above in your browser using DataLab