Learn R Programming

nlmixr2est (version 5.0.2)

.collectWarn: Collect warnings and just warn once.

Description

Collect warnings and just warn once.

Usage

.collectWarn(expr, lst = FALSE)

Value

The value of the expression or a list with the value of the expression and a list of warning messages

Arguments

expr

R expression

lst

When TRUE return a list with list(object,warnings) instead of issuing the warnings. Otherwise, when FALSE issue the warnings and return the object.

Author

Matthew L. Fidler