.deparseDifferent: Identify Differences Between Standard and New Objects but used in rxUiDeparse
Description
This function compares elements of a standard object with a new
object and identifies which elements are different. It is used to
only show values that are different from the default when deparsing
control objects.
A vector of indices indicating which elements of the
standard object differ from the new object.
Arguments
standard
The standard object used for comparison. (for example `foceiControl()`)
new
The new object to be compared against the standard. This
would be what the user supplide like
`foceiControl(outerOpt="bobyqa")`
internal
A character vector of element names to be ignored
during the comparison. Default is an empty character
vector. These are for internal items of the list that flag
certain properties like if the `rxControl()` was generated by the
`foceiControl()` procedure or not.