Learn R Programming

nlmixr2est (version 5.0.2)

.downgradeEtas: This downgrades the UI for any of the zero etas in the model

Description

This downgrades the UI for any of the zero etas in the model

Usage

.downgradeEtas(ui, zeroEtas = character(0))

Value

New rxode2 ui with the zero etas removed

Arguments

ui

rxode2 User interface function

zeroEtas

The names of the zero etas in the model

Author

Matthew L. Fidler