Learn R Programming

nlmixr2est (version 5.0.2)

.nlmixr2FitUpdateParams: Update model to have final parameter estimates for piping and save orig data

Description

Update model to have final parameter estimates for piping and save orig data

Usage

.nlmixr2FitUpdateParams(x)

Value

Nothing, called for side effects

Arguments

x

Data to fix