Learn R Programming

nlmixr2est (version 5.0.2)

.nlmixrNlmeFun: A surrogate function for nlme to call for ode solving

Description

A surrogate function for nlme to call for ode solving

Usage

.nlmixrNlmeFun(pars, id)

Value

Predictions

Arguments

pars

Parameters that will be estimated

id

The patient identifiers for the estimated data.

Author

Matthew L. Fidler

Details

This is an internal function and should not be called directly.