.nlmixrNlminbFunC: A surrogate function for nlminb to call for ode solving
Description
A surrogate function for nlminb to call for ode solving
Usage
.nlmixrNlminbFunC(pars).nlmixrNlminbGradC(pars)
.nlmixrNlminbHessC(pars)
Arguments
- pars
Parameters that will be estimated
Details
This is an internal function and should not be called directly.