Learn R Programming

nlmixr2est (version 5.0.2)

.nlmixrNlsFun: A surrogate function for nls to call for ode solving

Description

A surrogate function for nls to call for ode solving

Usage

.nlmixrNlsFun(DV, ...)

.nlmixrNlsFunValGrad(DV, ...)

Value

Predictions

Arguments

DV

dependent variable

...

Other parameters fed to prediction function

Author

Matthew L. Fidler

Details

This is an internal function and should not be called directly.