Learn R Programming

nlmixr2est (version 5.0.2)

.nlmixrOptimFunC: A surrogate function for optim to call for ode solving

Description

A surrogate function for optim to call for ode solving

Usage

.nlmixrOptimFunC(pars)

.nlmixrOptimGradC(pars)

Value

Predictions

Arguments

pars

Parameters that will be estimated

Author

Matthew L. Fidler

Details

This is an internal function and should not be called directly.