Whenever there is a fixed parameter in the model, the parameter is replaced with the literal value inside of the model and dropped from the `ini` block. This only occurs when the `control$literalFix=TRUE`.
.nlmixrPreprocessLiteralFix(ui, est, data, control)list with possibly updated ui
model function/object
estimation method (all methods are shown by `nlmixr2AllEst()`). Methods can be added for other tools
nlmixr data
The estimation control object. These are expected to be different for each type of estimation method
Matthew L. Fidler