Learn R Programming

nlmixr2est (version 5.0.2)

.uiApplyMu2: This is an internal function for modifying the UI to apply mu2 referencing

Description

mu2 referencing is algebraic mu-referencing by converting to the transformation to a single value in the original dataset, and moving that around

Usage

.uiApplyMu2(env)

Value

Either the original model() block (if changed) or NULL if not changed

Arguments

env

Environment needed for nlmixr2 fits

Author

Matthew L. Fidler