aaaCranNlmixrThreads: This function is to set the number of threads to 2

View source: R/aaaCranNlmixrThreads.R

aaaCranNlmixrThreadsR Documentation

This function is to set the number of threads to 2

Description

In general it is a CRAN requirement that packages not use more than 2 threads. This function is to set the number of threads to 2 for CRAN testing. It is not intended for general use.

Usage

aaaCranNlmixrThreads()

Details

When testing with devtools::test() or testthat::test_package(), the NOT_CRAN environment variable is set to "true", so the number of threads will not be limited to 2.

Value

nothing, called for side effect of setting the number of threads to 2 for CRAN testing

Author(s)

Matthew L. Fidler

Examples


# Set the number of threads to 2 for CRAN testing
aaaCranNlmixrThreads()


nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.