dot-agq: Get the adaptive Gauss-Hermite quadrature points and weights

.agqR Documentation

Get the adaptive Gauss-Hermite quadrature points and weights

Description

Get the adaptive Gauss-Hermite quadrature points and weights

Usage

.agq(neta = 2, nAGQ = 3)

Arguments

neta

number of eta parameters in the model

nAGQ

number of adaptive quadrature points to use

Value

A list with the following elements:

x

A matrix of quadrature points, one row per point.

w

A matrix of quadrature weights, one row per point.

n

The number of quadrature points.

neta

The number of eta parameters.

nAQD

The number of adaptive quadrature points.

first

A logical indicating if the first point is zero.

Author(s)

Matthew L. Fidler

Examples

.agq(neta=2, nAGQ=3)

nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.