dot-deparseDifferent: Identify Differences Between Standard and New Objects but...

.deparseDifferentR Documentation

Identify Differences Between Standard and New Objects but used in rxUiDeparse

Description

Compares elements of a standard object against a new one so 'rxUiDeparse' only shows values that differ from the default.

Usage

.deparseDifferent(standard, new, internal = character(0))

Arguments

standard

The standard object used for comparison. (for example 'foceiControl()')

new

The new object to be compared against the standard. This would be what the user supplide like 'foceiControl(outerOpt="bobyqa")'

internal

A character vector of element names to be ignored during the comparison. Default is an empty character vector. These are for internal items of the list that flag certain properties like if the 'rxControl()' was generated by the 'foceiControl()' procedure or not.

Value

A vector of indices indicating which elements of the standard object differ from the new object.

Author(s)

Matthew L. Fidler

Examples

standard <- list(a = 1, b = 2, c = 3)
new <- list(a = 1, b = 3, c = 3)
.deparseDifferent(standard, new)

nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.