dot-downgradeEtas: This downgrades the UI for any of the zero etas in the model

.downgradeEtasR Documentation

This downgrades the UI for any of the zero etas in the model

Description

This downgrades the UI for any of the zero etas in the model

Usage

.downgradeEtas(ui, zeroEtas = character(0))

Arguments

ui

rxode2 User interface function

zeroEtas

The names of the zero etas in the model

Value

New rxode2 ui with the zero etas removed

Author(s)

Matthew L. Fidler


nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.