dot-uiApplyMu2: This is an internal function for modifying the UI to apply...

.uiApplyMu2R Documentation

This is an internal function for modifying the UI to apply mu2 referencing

Description

mu2 referencing is algebraic mu-referencing by converting to the transformation to a single value in the original dataset, and moving that around

Usage

.uiApplyMu2(env)

.uiApplyMu2hook(ui, est, data, control)

Arguments

ui

the ui for the model

est

the estimation method

data

the data provided

control

the control object

Value

Either the original model() block (if changed) or NULL if not changed

Author(s)

Matthew L. Fidler


nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.