| foControl | R Documentation |
This is related to the focei methods and uses most of their control options. Some are ignored, 'posthoc' is an extra parameter
foControl(sigdig = 3, ..., posthoc = TRUE, interaction = NULL, fo = NULL)
sigdig |
Optimization significant digits. One value drives, with a single
consistent formula, the inner/outer optimizer convergence tolerance
( |
... |
Parameters used in the default 'foceiConrol()' |
posthoc |
Logical indicating if the estimation method should calculate 'foce' posthoc predicted parameters. |
interaction |
Interaction term for the model; ignored by fo |
fo |
Logical indicating if the estimation method is FO (first order), but this is controlled by the estimation method so this is ignored. |
foControl object
Matthew L. Fidler
foControl()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.