nlmGetParHist: Recover and finalize the resident nlm parameter history

View source: R/RcppExports.R

nlmGetParHistR Documentation

Recover and finalize the resident nlm parameter history

Description

Returns the parameter history accumulated in the resident nlm scaling struct (one row per iteration type per recorded evaluation) as a data frame, and stops further recording/printing (save and every are reset to 0). Must be called while .nlmSetupEnv() is still loaded – i.e. before .nlmFreeEnv(). Used by .nlmFinalizeList for the standard nlm-family estimators and directly by externally-optimized engines such as babelmixr2's nlmer.

Usage

nlmGetParHist(p = TRUE)

Arguments

p

When TRUE (default) also print the final iteration line.

Details

This is an internal function and should not be called directly.

Value

A data frame of the recorded parameter history.

Author(s)

Matthew L. Fidler


nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.