| nlmerSolveGrad | R Documentation |
Like the population gradient solver but takes a per-subject
nsub x ntheta parameter matrix (phi = beta + b, as
supplied by lme4::nlmer) instead of one shared theta.
Requires .nlmSetupEnv() to already be loaded.
nlmerSolveGrad(thetaMat, record = FALSE)
thetaMat |
A |
record |
When |
This is an internal function and should not be called directly.
A nobsTot x (ntheta+1) matrix in the loaded
(etTrans) observation order: column 1 is the prediction
(rx_pred_) and columns 2..(ntheta+1) are
d(pred)/d(THETA[i]).
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.