- theta
for the internal functions theta is the parameter
values
- md5
the md5 identifier for the internal gradient function
information.
- what
either a function or a non-empty character string naming the
function to be called.
- envir
an environment within which to evaluate the call. This
will be most useful if what is a character string and
the arguments are symbols or quoted expressions.
- which
Which parameters to calculate the forward difference
and optimal forward difference interval
- thetaNames
Names for the theta parameters
- gillRtol
The relative tolerance used for Gill 1983
determination of optimal step size.
- gillK
The total number of possible steps to determine the
optimal forward/central difference step size per parameter (by
the Gill 1983 method). If 0, no optimal step size is
determined. Otherwise this is the optimal step size
determined.
- gillStep
When looking for the optimal forward difference
step size, this is This is the step size to increase the
initial estimate by. So each iteration the new step size =
(prior step size)*gillStep
- gillFtol
The gillFtol is the gradient error tolerance that
is acceptable before issuing a warning/error about the gradient estimates.
- useColor
Boolean indicating if focei can use ASCII color codes
- printNcol
Number of columns to printout before wrapping
parameter estimates/gradient
- print
Integer representing when the outer step is
printed. When this is 0 or do not print the iterations. 1 is
print every function evaluation (default), 5 is print every 5
evaluations.