nlmixr2fix: Try to fix a nlmixr2 fit

View source: R/compat.R

nlmixr2fixR Documentation

Try to fix a nlmixr2 fit

Description

Re-evaluates the model function against the current version of rxode2, for fits created with an older nlmixr2/rxode2 version.

Usage

nlmixr2fix(fit)

Arguments

fit

nlmixr2 fit object from a different version of nlmixr2.

Value

A nlmixr2 fit that has been (possibly) adjusted to work with the current version of nlmixr2.

Author(s)

Matthew L. Fidler

Examples


## Not run: 
  # requires the qs package to read an older nlmixr2 v3 fit (qs is no
  # longer on CRAN); regenerates the rxode2 model so it works again
  # fit <- readRDS(system.file("testfit_nlmixr3.rds", package = "nlmixr2est"))
  # fit <- try(nlmixr2fix(fit))
  # if (!inherits(fit, "try-error")) rxSolve(fit)

## End(Not run)

nlmixr2est documentation built on Aug. 5, 2026, 1:11 a.m.