nmObjGetIpredModel: Get the ipred model for a fit object depending on the object...

View source: R/nmObjGet.R

nmObjGetIpredModelR Documentation

Get the ipred model for a fit object depending on the object type

Description

By default it gets the focei models if available.

Usage

nmObjGetIpredModel(x)

## S3 method for class 'saem'
nmObjGetIpredModel(x)

## Default S3 method:
nmObjGetIpredModel(x)

## S3 method for class 'saem'
nmObjGetEstimationModel(x)

## Default S3 method:
nmObjGetEstimationModel(x)

Arguments

x

nlmixr fit object

Value

ipred 'rxode2' model


nlmixr2est documentation built on Sept. 20, 2026, 9:08 a.m.