npObjAtGamma_: Diagnostic: NPAG objective at a fixed grid and residual...

View source: R/RcppExports.R

npObjAtGamma_R Documentation

Diagnostic: NPAG objective at a fixed grid and residual multiplier gamma

Description

Diagnostic: NPAG objective at a fixed grid and residual multiplier gamma

Usage

npObjAtGamma_(etaPoints, cores, gamma)

Arguments

etaPoints

support points, one per row

cores

threads

gamma

residual-error multiplier

Value

offset-corrected marginal log-likelihood


nlmixr2est documentation built on Sept. 20, 2026, 9:08 a.m.