Learn R Programming

nlmixr2est (version 5.0.2)

rxGetDistributionFoceiLines: This is a S3 method for getting the distribution lines for a base rxode2 focei problem

Description

This is a S3 method for getting the distribution lines for a base rxode2 focei problem

Usage

rxGetDistributionFoceiLines(line)

Value

Lines for the focei. This is based on the idea that the focei parameters are defined

Arguments

line

Parsed rxode2 model environment

Author

Matthew Fidler