Learn R Programming

nlmixr2est (version 5.0.2)

sqrtm: Return the square root of general square matrix A

Description

Return the square root of general square matrix A

Usage

sqrtm(m)

Value

A square root general square matrix of m

Arguments

m

Matrix to take the square root of.