powered by
Get the adaptive Gauss-Hermite quadrature points and weights
.agq(neta = 2, nAGQ = 3)
A list with the following elements:
A matrix of quadrature points, one row per point.
A matrix of quadrature weights, one row per point.
The number of quadrature points.
The number of eta parameters.
The number of adaptive quadrature points.
A logical indicating if the first point is zero.
number of eta parameters in the model
number of adaptive quadrature points to use
Matthew L. Fidler
.agq(neta=2, nAGQ=3)
Run the code above in your browser using DataLab