.nlmixr2FitUpdateParams: Update model to have final parameter estimates for piping and save orig data
Description
Update model to have final parameter estimates for piping and save orig data
Usage
.nlmixr2FitUpdateParams(x)
Value
Nothing, called for side effects