powered by
A surrogate function for nlme to call for ode solving
.nlmixrNlmeFun(pars, id)
Predictions
Parameters that will be estimated
The patient identifiers for the estimated data.
Matthew L. Fidler
This is an internal function and should not be called directly.