.nlmixrNlsFun: A surrogate function for nls to call for ode solving
Description
A surrogate function for nls to call for ode solving
Usage
.nlmixrNlsFun(DV, ...).nlmixrNlsFunValGrad(DV, ...)
Arguments
- DV
dependent variable
- ...
Other parameters fed to prediction function
Details
This is an internal function and should not be called directly.