powered by
mu2 referencing is algebraic mu-referencing by converting to the transformation to a single value in the original dataset, and moving that around
.uiApplyMu2(env)
Either the original model() block (if changed) or NULL if not changed
Environment needed for nlmixr2 fits
Matthew L. Fidler