.uiFinalizeMu2: This is an internal function for replacing the ui with original
model and dropping artificial data in output
Description
This is an internal function for replacing the ui with original
model and dropping artificial data in output
Usage
.uiFinalizeMu2(ret, model)
Value
modified fit updated to show the original model and without
the internal transformations
Arguments
- ret
The object that would be returned, without modification
- model
The original model to apply