View source: R/aaaCranNlmixrThreads.R
| aaaCranNlmixrThreads | R Documentation |
In general it is a CRAN requirement that packages not use more than 2 threads. This function is to set the number of threads to 2 for CRAN testing. It is not intended for general use.
aaaCranNlmixrThreads()
When testing with devtools::test() or testthat::test_package(), the NOT_CRAN environment variable is set to "true", so the number of threads will not be limited to 2.
nothing, called for side effect of setting the number of threads to 2 for CRAN testing
Matthew L. Fidler
# Set the number of threads to 2 for CRAN testing
aaaCranNlmixrThreads()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.