| .agq | R Documentation |
Get the adaptive Gauss-Hermite quadrature points and weights
.agq(neta = 2, nAGQ = 3)
neta |
number of eta parameters in the model |
nAGQ |
number of adaptive quadrature points to use |
A list with the following elements:
x |
A matrix of quadrature points, one row per point. |
w |
A matrix of quadrature weights, one row per point. |
n |
The number of quadrature points. |
neta |
The number of eta parameters. |
nAQD |
The number of adaptive quadrature points. |
first |
A logical indicating if the first point is zero. |
Matthew L. Fidler
.agq(neta=2, nAGQ=3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.