| .collectWarn | R Documentation |
Collect warnings and just warn once.
.collectWarn(expr, lst = FALSE, collectErr = FALSE)
expr |
R expression |
lst |
When |
collectErr |
When |
The value of the expression, or when lst = TRUE a
list of the form list(object, warning = ws, error = es)
where ws and es are character vectors of unique
warning and error messages (es is always NULL
when collectErr = FALSE, and is also NULL when
the expression evaluated successfully under collectErr =
TRUE).
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.