| .deparseDifferent | R Documentation |
Compares elements of a standard object against a new one so 'rxUiDeparse' only shows values that differ from the default.
.deparseDifferent(standard, new, internal = character(0))
standard |
The standard object used for comparison. (for example 'foceiControl()') |
new |
The new object to be compared against the standard. This would be what the user supplide like 'foceiControl(outerOpt="bobyqa")' |
internal |
A character vector of element names to be ignored during the comparison. Default is an empty character vector. These are for internal items of the list that flag certain properties like if the 'rxControl()' was generated by the 'foceiControl()' procedure or not. |
A vector of indices indicating which elements of the standard object differ from the new object.
Matthew L. Fidler
standard <- list(a = 1, b = 2, c = 3)
new <- list(a = 1, b = 3, c = 3)
.deparseDifferent(standard, new)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.