| .downgradeEtas | R Documentation |
This downgrades the UI for any of the zero etas in the model
.downgradeEtas(ui, zeroEtas = character(0))
ui |
rxode2 User interface function |
zeroEtas |
The names of the zero etas in the model |
New rxode2 ui with the zero etas removed
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.