This is an internal function for modifying the UI to apply mu2 referencing
Source:R/mu2.R
dot-uiApplyMu2.Rdmu2 referencing is algebraic mu-referencing by converting to the transformation to a single value in the original dataset, and moving that around