| .uiApplyMu2 | R Documentation |
mu2 referencing is algebraic mu-referencing by converting to the transformation to a single value in the original dataset, and moving that around
.uiApplyMu2(env)
.uiApplyMu2hook(ui, est, data, control)
ui |
the ui for the model |
est |
the estimation method |
data |
the data provided |
control |
the control object |
Either the original model() block (if changed) or NULL if not changed
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.