| foceControl | R Documentation |
This is the first order option without the interaction between residuals and etas.
foceControl(sigdig = 3, ..., interaction = FALSE)
sigdig |
Optimization significant digits. One value drives, with a single
consistent formula, the inner/outer optimizer convergence tolerance
( |
... |
Parameters used in the default 'foceiControl()' |
interaction |
Interaction term for the model, in this case the default is 'FALSE'; it cannot be changed, use 'focei' instead |
foceControl object
Matthew L. Fidler
foceControl()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.