| focepControl | R Documentation |
This is the first order conditional estimation without eta/residual interaction, but keeping the live conditional residual variance R (the 'foce = "foce+"' option of [foceiControl()]). It is the 'foce' method with 'foce = "foce+"' forced; use 'foce' (est = "foce") for the NONMEM-matching frozen-R behavior.
focepControl(sigdig = 3, ..., interaction = FALSE, foce = "foce+")
sigdig |
Optimization significant digits. One value drives, with a single
consistent formula, the inner/outer optimizer convergence tolerance
( |
... |
Parameters used in the default 'foceiControl()' |
interaction |
Interaction term for the model, in this case the default is 'FALSE'; it cannot be changed, use 'focei' instead |
foce |
FOCE residual-variance mode; for 'focepControl()' this is always '"foce+"' and cannot be changed – use 'foceControl()' for '"nonmem"' |
focepControl object
Matthew L. Fidler
focepControl()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.