| nlmGetParHist | R Documentation |
Returns the parameter history accumulated in the resident nlm scaling
struct (one row per iteration type per recorded evaluation) as a data
frame, and stops further recording/printing (save and every
are reset to 0). Must be called while .nlmSetupEnv() is still
loaded – i.e. before .nlmFreeEnv(). Used by .nlmFinalizeList
for the standard nlm-family estimators and directly by externally-optimized
engines such as babelmixr2's nlmer.
nlmGetParHist(p = TRUE)
p |
When |
This is an internal function and should not be called directly.
A data frame of the recorded parameter history.
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.