Generic for nlmixr2 estimation methods
# S3 method for agq
nlmixr2Est(env, ...)# S3 method for bobyqa
nlmixr2Est(env, ...)
# S3 method for fo
nlmixr2Est(env, ...)
# S3 method for foce
nlmixr2Est(env, ...)
# S3 method for focei
nlmixr2Est(env, ...)
# S3 method for output
nlmixr2Est(env, ...)
# S3 method for foi
nlmixr2Est(env, ...)
# S3 method for laplace
nlmixr2Est(env, ...)
# S3 method for lbfgsb3c
nlmixr2Est(env, ...)
# S3 method for n1qn1
nlmixr2Est(env, ...)
# S3 method for newuoa
nlmixr2Est(env, ...)
# S3 method for nlm
nlmixr2Est(env, ...)
# S3 method for nlme
nlmixr2Est(env, ...)
# S3 method for nlminb
nlmixr2Est(env, ...)
nlmixr2Est(env, ...)
# S3 method for default
nlmixr2Est(env, ...)
# S3 method for nls
nlmixr2Est(env, ...)
# S3 method for optim
nlmixr2Est(env, ...)
# S3 method for posthoc
nlmixr2Est(env, ...)
# S3 method for rxSolve
nlmixr2Est(env, ...)
# S3 method for simulate
nlmixr2Est(env, ...)
# S3 method for simulation
nlmixr2Est(env, ...)
# S3 method for predict
nlmixr2Est(env, ...)
# S3 method for saem
nlmixr2Est(env, ...)
# S3 method for uobyqa
nlmixr2Est(env, ...)
nlmixr2 fit object
Environment for the nlmixr2 estimation routines.
This needs to have:
- rxode2 ui object in `$ui`
- data to fit in the estimation routine in `$data`
- control for the estimation routine's control options in `$ui`
Other arguments provided to `nlmixr2Est()` provided for flexibility but not currently used inside nlmixr
Matthew Fidler
This is a S3 generic that allows others to use the nlmixr2 environment to do their own estimation routines