This allows the suppressMessages to work on print functions. This
captures the output function sends it through the message routine.
Usage
nlmixr2Print(x, ...)
Value
Nothing, called for its side effects
Arguments
x
object to print
...
Other things output
Author
Matthew L. Fidler
Details
catpureOutput was used since it is much faster than the internal
capture.output see https://www.r-bloggers.com/performance-captureoutput-is-much-faster-than-capture-output/