Re-evaluates the model function against the current version of rxode2, for fits created with an older nlmixr2/rxode2 version.
Examples
if (FALSE) { # \dontrun{
# requires the qs package to read an older nlmixr2 v3 fit (qs is no
# longer on CRAN); regenerates the rxode2 model so it works again
# fit <- readRDS(system.file("testfit_nlmixr3.rds", package = "nlmixr2est"))
# fit <- try(nlmixr2fix(fit))
# if (!inherits(fit, "try-error")) rxSolve(fit)
} # }