| nlmixr2fix | R Documentation |
Re-evaluates the model function against the current version of rxode2, for fits created with an older nlmixr2/rxode2 version.
nlmixr2fix(fit)
fit |
nlmixr2 fit object from a different version of nlmixr2. |
A nlmixr2 fit that has been (possibly) adjusted to work with the current version of nlmixr2.
Matthew L. Fidler
## Not run:
# requires the qs package to read an older nlmixr2 v3 fit (qs is no
# longer on CRAN); regenerates the rxode2 model so it works again
# fit <- readRDS(system.file("testfit_nlmixr3.rds", package = "nlmixr2est"))
# fit <- try(nlmixr2fix(fit))
# if (!inherits(fit, "try-error")) rxSolve(fit)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.