Get an item from a nlmixr2FitData object
# S3 method for addCwres
nmObjGetData(x, ...)nmObjGetData(x, ...)
# S3 method for dataMergeLeft
nmObjGetData(x, ...)
# S3 method for dataMergeRight
nmObjGetData(x, ...)
# S3 method for dataMergeInner
nmObjGetData(x, ...)
# S3 method for dataMergeFull
nmObjGetData(x, ...)
# S3 method for fitMergeLeft
nmObjGetData(x, ...)
# S3 method for fitMergeRight
nmObjGetData(x, ...)
# S3 method for fitMergeInner
nmObjGetData(x, ...)
# S3 method for fitMergeFull
nmObjGetData(x, ...)
Value of argument or NULL
A specialized list with: - First argument is a nlmixr2FitData object - Second argument is if the exact argument is requested - The class would be the requested argument name followed by the class "nmObjGet"
Other arguments
Matthew L. Fidler