| posthocControl | R Documentation |
This option is for simply getting the maximum a-prior (MAP) also called the posthoc estimates
posthocControl(sigdig = 3, ..., interaction = FALSE, maxOuterIterations = NULL)
sigdig |
Optimization significant digits. One value drives, with a single
consistent formula, the inner/outer optimizer convergence tolerance
( |
... |
Parameters used in the default 'foceiConrol()' |
interaction |
Interaction term for the model, in this case the default is 'FALSE', though you can set it to be 'TRUE' as well. |
maxOuterIterations |
ignored, posthoc always sets this to 0. |
posthocControl object
Matthew L. Fidler
posthocControl()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.