rxGetDistributionNlsLines: This is a S3 method for getting the distribution lines for a base rxode2 nls problem
Description
This is a S3 method for getting the distribution lines for a base rxode2 nls problem
Usage
rxGetDistributionNlsLines(line)# S3 method for norm
rxGetDistributionNlsLines(line)
# S3 method for default
rxGetDistributionNlsLines(line)
Value
Lines for the focei. This is based
on the idea that the focei parameters are defined
Arguments
- line
Parsed rxode2 model environment