Learn R Programming

nlmixr2est (version 5.0.2)

setCov: Set the covariance type based on prior calculated covariances

Description

Set the covariance type based on prior calculated covariances

Usage

setCov(fit, method)

Value

Fit object with covariance updated

Arguments

fit

nlmixr2 fit

method

covariance method (see the `covMethod` argument for the control options for the choices)

Author

Matt Fidler

See Also

foceiControl(), saemControl()