VPC simulation
Usage
vpcSim(
object,
...,
keep = NULL,
n = 300,
pred = FALSE,
seed = 1009,
nretry = 50,
minN = 10,
normRelated = TRUE
)Arguments
- object
This is the nlmixr2 fit object
- ...
Other arguments sent to `rxSolve()`
- keep
Column names to keep in the output simulated dataset
- n
Number of simulations
- pred
Should predictions be added to the simulation
- seed
Seed to set for the VPC simulation
- nretry
Number of times to retry the simulation if there is NA values in the simulation
- minN
With retries, the minimum number of studies to restimulate (by default 10)
should the VPC style simulation be for normal related variables only
Examples
# \donttest{
one.cmt <- function() {
ini({
## You may label each parameter with a comment
tka <- 0.45 # Log Ka
tcl <- log(c(0, 2.7, 100)) # Log Cl
## This works with interactive models
## You may also label the preceding line with label("label text")
tv <- 3.45; label("log V")
## the label("Label name") works with all models
eta.ka ~ 0.6
eta.cl ~ 0.3
eta.v ~ 0.1
add.sd <- 0.7
})
model({
ka <- exp(tka + eta.ka)
cl <- exp(tcl + eta.cl)
v <- exp(tv + eta.v)
linCmt() ~ add(add.sd)
})
}
fit <- nlmixr(one.cmt, theo_sd, est="focei")
#>
#>
#>
#>
#> ℹ parameter labels from comments are typically ignored in non-interactive mode
#> ℹ Need to run with the source intact to parse comments
#> → Calculating residuals/tables
#> ✔ done
#> Warning: gradient problems with initial estimate and covariance; see $scaleInfo
#> Warning: ETAs were reset to zero during optimization; (Can control by foceiControl(resetEtaP=.))
#> Warning: initial ETAs were nudged; (can control by foceiControl(etaNudge=., etaNudge2=))
head(vpcSim(fit, pred=TRUE))
#>
#>
#> sim.id id time ipred sim tad depot central nlmixrRowNums
#> 1 1 1 0.00 0.000000 -0.2596802 0.00 319.99200000 0.0000 2
#> 2 1 1 0.25 4.252698 3.8700870 0.25 170.25895023 148.4345 3
#> 3 1 1 0.57 6.839730 7.2113993 0.57 75.91937329 238.7313 4
#> 4 1 1 1.12 8.204266 7.2536392 1.12 18.94473093 286.3585 5
#> 5 1 1 2.02 8.219393 8.2581311 2.02 1.95426490 286.8865 6
#> 6 1 1 3.82 7.386697 7.6537916 3.82 0.02079569 257.8224 7
#> rxLambda rxYj rxLow rxHi pred
#> 1 1 2 0 1 0.000000
#> 2 1 2 0 1 3.264110
#> 3 1 2 0 1 5.832395
#> 4 1 2 0 1 7.868348
#> 5 1 2 0 1 8.508967
#> 6 1 2 0 1 7.623610
# }